==> ec2-0.23.0-sources.jar: software/amazon/awscdk/services/ec2/CfnVPNConnection.java <==
package software.amazon.awscdk.services.ec2;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-connection.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.14 (build 91853ce)", date = "2019-02-04T14:53:02.976Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnVPNConnection")
public class CfnVPNConnection extends software.amazon.awscdk.Resource {
    protected CfnVPNConnection(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.CfnVPNConnection.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPNConnection``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnVPNConnection(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.CfnVPNConnectionProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.CfnVPNConnectionProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.CfnVPNConnectionProps.class);
    }

    public java.lang.String getVpnConnectionName() {
        return this.jsiiGet("vpnConnectionName", java.lang.String.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html
     */
    public static interface VpnTunnelOptionsSpecificationProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
         */
        java.lang.String getPreSharedKey();
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
         */
        void setPreSharedKey(final java.lang.String value);
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
         */
        java.lang.String getTunnelInsideCidr();
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
         */
        void setTunnelInsideCidr(final java.lang.String value);

        /**
         * @return a {@link Builder} of {@link VpnTunnelOptionsSpecificationProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link VpnTunnelOptionsSpecificationProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.String _preSharedKey;
            @javax.annotation.Nullable
            private java.lang.String _tunnelInsideCidr;

            /**
             * Sets the value of PreSharedKey
             * @param value ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
             * @return {@code this}
             */
            public Builder withPreSharedKey(@javax.annotation.Nullable final java.lang.String value) {
                this._preSharedKey = value;
                return this;
            }
            /**
             * Sets the value of TunnelInsideCidr
             * @param value ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
             * @return {@code this}
             */
            public Builder withTunnelInsideCidr(@javax.annotation.Nullable final java.lang.String value) {
                this._tunnelInsideCidr = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link VpnTunnelOptionsSpecificationProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public VpnTunnelOptionsSpecificationProperty build() {
                return new VpnTunnelOptionsSpecificationProperty() {
                    @javax.annotation.Nullable
                    private java.lang.String $preSharedKey = _preSharedKey;
                    @javax.annotation.Nullable
                    private java.lang.String $tunnelInsideCidr = _tunnelInsideCidr;

                    @Override
                    public java.lang.String getPreSharedKey() {
                        return this.$preSharedKey;
                    }

                    @Override
                    public void setPreSharedKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$preSharedKey = value;
                    }

                    @Override
                    public java.lang.String getTunnelInsideCidr() {
                        return this.$tunnelInsideCidr;
                    }

                    @Override
                    public void setTunnelInsideCidr(@javax.annotation.Nullable final java.lang.String value) {
                        this.$tunnelInsideCidr = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnVPNConnection.VpnTunnelOptionsSpecificationProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getPreSharedKey() {
                return this.jsiiGet("preSharedKey", java.lang.String.class);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
             */
            @Override
            public void setPreSharedKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("preSharedKey", value);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getTunnelInsideCidr() {
                return this.jsiiGet("tunnelInsideCidr", java.lang.String.class);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
             */
            @Override
            public void setTunnelInsideCidr(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("tunnelInsideCidr", value);
            }
        }
    }
}

==> ec2-0.24.0-sources.jar: software/amazon/awscdk/services/ec2/CfnVPNConnection.java <==
package software.amazon.awscdk.services.ec2;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpn-connection.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.14 (build 91853ce)", date = "2019-02-07T11:13:17.933Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnVPNConnection")
public class CfnVPNConnection extends software.amazon.awscdk.Resource {
    protected CfnVPNConnection(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.CfnVPNConnection.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPNConnection``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnVPNConnection(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.CfnVPNConnectionProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.CfnVPNConnectionProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.CfnVPNConnectionProps.class);
    }

    /**
     * The ``TagManager`` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. ``Tag`` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }

    public java.lang.String getVpnConnectionName() {
        return this.jsiiGet("vpnConnectionName", java.lang.String.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html
     */
    public static interface VpnTunnelOptionsSpecificationProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
         */
        java.lang.String getPreSharedKey();
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
         */
        void setPreSharedKey(final java.lang.String value);
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
         */
        java.lang.String getTunnelInsideCidr();
        /**
         * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
         */
        void setTunnelInsideCidr(final java.lang.String value);

        /**
         * @return a {@link Builder} of {@link VpnTunnelOptionsSpecificationProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link VpnTunnelOptionsSpecificationProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.String _preSharedKey;
            @javax.annotation.Nullable
            private java.lang.String _tunnelInsideCidr;

            /**
             * Sets the value of PreSharedKey
             * @param value ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
             * @return {@code this}
             */
            public Builder withPreSharedKey(@javax.annotation.Nullable final java.lang.String value) {
                this._preSharedKey = value;
                return this;
            }
            /**
             * Sets the value of TunnelInsideCidr
             * @param value ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
             * @return {@code this}
             */
            public Builder withTunnelInsideCidr(@javax.annotation.Nullable final java.lang.String value) {
                this._tunnelInsideCidr = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link VpnTunnelOptionsSpecificationProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public VpnTunnelOptionsSpecificationProperty build() {
                return new VpnTunnelOptionsSpecificationProperty() {
                    @javax.annotation.Nullable
                    private java.lang.String $preSharedKey = _preSharedKey;
                    @javax.annotation.Nullable
                    private java.lang.String $tunnelInsideCidr = _tunnelInsideCidr;

                    @Override
                    public java.lang.String getPreSharedKey() {
                        return this.$preSharedKey;
                    }

                    @Override
                    public void setPreSharedKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$preSharedKey = value;
                    }

                    @Override
                    public java.lang.String getTunnelInsideCidr() {
                        return this.$tunnelInsideCidr;
                    }

                    @Override
                    public void setTunnelInsideCidr(@javax.annotation.Nullable final java.lang.String value) {
                        this.$tunnelInsideCidr = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnVPNConnection.VpnTunnelOptionsSpecificationProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getPreSharedKey() {
                return this.jsiiGet("preSharedKey", java.lang.String.class);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.PreSharedKey``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-presharedkey
             */
            @Override
            public void setPreSharedKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("preSharedKey", value);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getTunnelInsideCidr() {
                return this.jsiiGet("tunnelInsideCidr", java.lang.String.class);
            }

            /**
             * ``CfnVPNConnection.VpnTunnelOptionsSpecificationProperty.TunnelInsideCidr``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-vpnconnection-vpntunneloptionsspecification.html#cfn-ec2-vpnconnection-vpntunneloptionsspecification-tunnelinsidecidr
             */
            @Override
            public void setTunnelInsideCidr(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("tunnelInsideCidr", value);
            }
        }
    }
}
